@@ -10,8 +10,8 @@ year = datetime.now().year
 
 __author__ = "Viso.ai team"
 __copyright__ = f"Copyright 2020-{year} viso.ai AG <info@viso.ai>"
-__email__ = "s.carlyon@viso.ai"
+__email__ = "g.corrigan@viso.ai"
 __license__ = "LGPL3"
 __title__ = "viso-sdk-python"
 
-__version__ = "0.0.10"
+__version__ = "0.0.13"
